Posterior Distance Distributions (`ligo.skymap.distance`)
=========================================================

.. automodule:: ligo.skymap.distance

Conditional Distributions
-------------------------

.. autofunction:: conditional_pdf
.. autofunction:: conditional_cdf
.. autofunction:: conditional_ppf

Moments
-------

.. autofunction:: moments_to_parameters
.. autofunction:: parameters_to_moments
.. autofunction:: parameters_to_marginal_moments

Marginal Distributions
----------------------

.. autofunction:: marginal_pdf
.. autofunction:: marginal_cdf
.. autofunction:: marginal_ppf

Kernel Density Estimation
-------------------------

.. autofunction:: conditional_kde
.. autofunction:: cartesian_kde_to_moments

Miscellaneous
-------------

.. autofunction:: ud_grade
.. autofunction:: volume_render
.. autofunction:: principal_axes
